==> simple_search_bar-0.0.20.tar.gz: lib/src/simple_search_bar.dart <==
import 'package:flutter/material.dart';
import 'app_bar_controller.dart';

class SearchAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Color statusBarColor;
  final Color primary;
  final bool autoSelected;
  final AppBar mainAppBar;
  final Color mainTextColor;
  final double searchWidth;
  final String searchHint;
  final AppBarController appBarController;
  final Function(String search) onChange;

  SearchAppBar({
    @required this.primary,
    this.mainTextColor = Colors.white,
    this.statusBarColor,
    this.autoSelected = false,
    this.searchHint = "Search here...",
    @required this.mainAppBar,
    @required this.appBarController,
    @required this.onChange,
    this.searchWidth,
  });

  @override
  Size get preferredSize {
    return Size.fromHeight(60.0);
  }

  Widget build(BuildContext context) {
    appBarController.stream.add(autoSelected);

    return StreamBuilder(
      stream: appBarController.stream.stream,
      builder: (BuildContext context, AsyncSnapshot<bool> snap) {
        if (snap.hasData) {
          appBarController.state = snap.data;
        }

        if (appBarController.state) {
          return searchAppBar(
            context: context,
          );
        } else {
          return showMainAppBar();
        }
      },
    );
  }

  Widget showMainAppBar() {
    return mainAppBar;
  }

  Widget searchAppBar({@required BuildContext context}) {
    
    double _searchWidth = MediaQuery.of(context).size.width - 50;

    if(searchWidth == null){
      _searchWidth = searchWidth;
    }

    return AppBar(
      leading: InkWell(
        child: Icon(
          Icons.close,
          color: mainTextColor,
        ),
        onTap: () {
          appBarController.stream.add(false);
        },
      ),
      backgroundColor: primary,
      title: Container(
        width: _searchWidth,
        child: TextField(
          autofocus: true,
          onChanged: (String value) {
            onChange(value);
          },
          cursorColor: mainTextColor,
          decoration: InputDecoration(
            hintText: searchHint,
            border: InputBorder.none,
            hintStyle: TextStyle(
              color: mainTextColor.withAlpha(100),
            ),
            prefixIcon: Icon(Icons.search),
          ),
        ),
      ),
    );
  }
}

==> simple_search_bar-0.0.23.tar.gz: lib/src/simple_search_bar.dart <==
import 'package:flutter/material.dart';
import 'app_bar_controller.dart';

class SearchAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Color statusBarColor;
  final Color primary;
  final bool autoSelected;
  final AppBar mainAppBar;
  final Color mainTextColor;
  final double searchWidth;
  final String searchHint;
  final AppBarController appBarController;
  final Function(String search) onChange;

  SearchAppBar({
    @required this.primary,
    this.mainTextColor = Colors.white,
    this.statusBarColor,
    this.autoSelected = false,
    this.searchHint = "Search here...",
    @required this.mainAppBar,
    @required this.appBarController,
    @required this.onChange,
    this.searchWidth,
  });

  @override
  Size get preferredSize {
    return Size.fromHeight(60.0);
  }

  Widget build(BuildContext context) {
    appBarController.stream.add(autoSelected);

    return StreamBuilder(
      stream: appBarController.stream.stream,
      builder: (BuildContext context, AsyncSnapshot<bool> snap) {
        if (snap.hasData) {
          appBarController.state = snap.data;
        }

        if (appBarController.state) {
          return searchAppBar(
            context: context,
          );
        } else {
          return showMainAppBar();
        }
      },
    );
  }

  Widget showMainAppBar() {
    return mainAppBar;
  }

  Widget searchAppBar({@required BuildContext context}) {
    
    // double _searchWidth = MediaQuery.of(context).size.width - 40;

    // if(searchWidth == null){
    //   _searchWidth = searchWidth;
    // }

    return AppBar(
      leading: InkWell(
        child: Icon(
          Icons.close,
          color: mainTextColor,
        ),
        onTap: () {
          appBarController.stream.add(false);
        },
      ),
      backgroundColor: primary,
      title: Container(
        decoration: BoxDecoration(
          color: Colors.yellow,
        ),
        // width: _searchWidth,
        child: TextField(
          autofocus: true,
          onChanged: (String value) {
            onChange(value);
          },
          cursorColor: mainTextColor,
          decoration: InputDecoration(
            hintText: searchHint,
            border: InputBorder.none,
            hintStyle: TextStyle(
              color: mainTextColor.withAlpha(100),
            ),
            suffixIcon: Icon(Icons.search,color: mainTextColor.withAlpha(100),),
          ),
        ),
      ),
    );
  }
}
